import os
import importlib.util

from typing import Dict

from tensorflow.keras.models import Model, load_model
from tensorflow.python.keras.engine.functional import Functional


TERRA_AI_PATH = "/content/drive/MyDrive/TerraAI"


class TerraProject:
    name: str
    h5: Dict[str, Functional]
    model: Model

    def __init__(self, name: str):
        self.name = name
        self.h5 = {}
        self.model = None
        try:
            for item in os.listdir(self.project_path):
                if item.endswith(".h5"):
                    name = item.split(".")
                    name.pop()
                    self.h5.update(
                        {name.pop(): load_model(os.path.join(self.project_path, item))}
                    )
                if item.endswith(".py"):
                    self.model = self.load_keras(os.path.join(self.project_path, item))
        except FileNotFoundError as error:
            print(f"Не удалось прочитать проект «{self.name}»")

    def __str__(self):
        return f"""<{self.__class__.__name__}> {self.name}
h5: {self.h5}
model: {self.model}"""

    def __repr__(self):
        return self.__str__()

    @property
    def project_path(self) -> str:
        return os.path.join(TERRA_AI_PATH, "projects", self.name)

    def load_keras(self, filepath: str) -> Model:
        spec = importlib.util.spec_from_file_location("keras", filepath)
        module = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(module)
        return module.model



import requests

from argparse import ArgumentParser
from google.colab import drive


def auth():
    parser = ArgumentParser()
    parser.add_argument("--email", type=str)
    parser.add_argument("--token", type=str)
    parser.add_argument("--url", type=str)
    args = parser.parse_args()

    response = requests.post(
        args.url, json={"email": args.email, "user_token": args.token}
    )
    if not response.ok:
        print("Ошибка запроса авторизации! Попробуйте позже...")
        return

    data = response.json()

    if not data.get("success"):
        print(data.get("error"))
        return

    files = data.get("data").get("create")
    for name, info in files.items():
        with open(info.get("name"), "w") as file:
            file.write(info.get("data"))

    with open("/content/terra_gui/.terra-gui.env", "a") as file:
        file.write(f'TERRA_GUI_URL={data.get("data").get("url")}\n')


def gdmount():
    drive.mount("/content/drive")



#!/usr/bin/env python3

__version__ = "0.3.1"

from setuptools import setup, find_packages


setup(
    name="terra_colab",
    version=__version__,
    packages=find_packages(),
    long_description=open("README.rst").read(),
    install_requires=[
        "tensorflow==2.5.0",
        "dill>=0.3.4",
        "requests~=2.23.0",
        "folium==0.2.1",
        "pymorphy2>=0.9.1",
        "six~=1.15.0",
        "Jinja2<3.0,>=2.10.1",
        "Werkzeug<2.0,>=0.15",
        "imgaug<0.2.7,>=0.2.5",
        "Django==3.2",
        "django-environ==0.4.5",
        "djangorestframework==3.12.4",
        "django_compressor==2.4.1",
        "django-htmlmin==0.11.0",
        "pydantic>=1.8.2",
        "cairosvg==2.5.2",
        "PyYAML==5.4.1",
        "absl-py==0.12.0",
        "scipy==1.4.1",
        "numpy~=1.19.2",
        "transliterate==1.10.2",
    ],
    entry_points={
        "console_scripts": [
            "tc-auth = terra_colab.commands:auth",
            "tc-gdmount = terra_colab.commands:gdmount",
        ]
    },
    scripts=[
        "scripts/tc-init",
        "scripts/tc-web",
    ],
)
